<?php
/********************************************************************/
/* EXCERPT RELOADED FUNCTIONS */
/********************************************************************/

function wp_the_excerpt_reloaded($args='') {
    parse_str($args);
    if(!isset($excerpt_length)) $excerpt_length = 40; // length of excerpt in words. -1 to display all excerpt/content
    if(!isset($allowedtags)) $allowedtags = '<a>'; // HTML tags allowed in excerpt, 'all' to allow all tags.
    if(!isset($filter_type)) $filter_type = 'excerpt'; // format filter used => 'content', 'excerpt', 'content_rss', 'excerpt_rss', 'none'
    if(!isset($use_more_link)) $use_more_link = 1; // display
    if(!isset($more_link_text)) $more_link_text = "(more...)";
    if(!isset($force_more)) $force_more = 1;
    if(!isset($fakeit)) $fakeit = 1;
    if(!isset($fix_tags)) $fix_tags = 1;
    if(!isset($no_more)) $no_more = 0;
    if(!isset($more_tag)) $more_tag = 'div';
    if(!isset($more_link_title)) $more_link_title = 'Continue reading this entry';
    if(!isset($showdots)) $showdots = 1;

    return the_excerpt_reloaded($excerpt_length, $allowedtags, $filter_type, $use_more_link, $more_link_text, $force_more, $fakeit, $fix_tags, $no_more, $more_tag, $more_link_title, $showdots);
}

function the_excerpt_reloaded($excerpt_length=120, $allowedtags='<a>', $filter_type='none', $use_more_link=true, $more_link_text="(more...)", $force_more=true, $fakeit=1, $fix_tags=true, $no_more=false, $more_tag='div', $more_link_title='Continue reading this entry', $showdots=true) {
    if(preg_match('%^content($|_rss)|^excerpt($|_rss)%', $filter_type)) {
        $filter_type = 'the_' . $filter_type;
    }
    echo get_the_excerpt_reloaded($excerpt_length, $allowedtags, $filter_type, $use_more_link, $more_link_text, $force_more, $fakeit, $no_more, $more_tag, $more_link_title, $showdots);
}

function get_the_excerpt_reloaded($excerpt_length, $allowedtags, $filter_type, $use_more_link, $more_link_text, $force_more, $fakeit, $no_more, $more_tag, $more_link_title, $showdots) {
    global $post;

    if (!empty($post->post_password)) { // if there's a password
        if ($_COOKIE['wp-postpass_'.COOKIEHASH] != $post->post_password) { // and it doesn't match cookie
            if(is_feed()) { // if this runs in a feed
                $output = __('There is no excerpt because this is a protected post.');
            } else {
                $output = get_the_password_form();
            }
        }
        return $output;
    }

    if($fakeit == 2) { // force content as excerpt
        $text = $post->post_content;
    } elseif($fakeit == 1) { // content as excerpt, if no excerpt
        $text = (empty($post->post_excerpt)) ? $post->post_content : $post->post_excerpt;
    } else { // excerpt no matter what
        $text = $post->post_excerpt;
    }

    if($excerpt_length < 0) {
        $output = $text;
    } else {
        if(!$no_more && strpos($text, '<!--more-->')) {
            $text = explode('<!--more-->', $text, 2);
            $l = count($text[0]);
            $more_link = 1;
        } else {
            $text = explode(' ', $text);
            if(count($text) > $excerpt_length) {
                $l = $excerpt_length;
                $ellipsis = 1;
            } else {
                $l = count($text);
                $more_link_text = '';
                $ellipsis = 0;
            }
        }
        for ($i=0; $i<$l; $i++)
                $output .= $text[$i] . ' ';
    }

    if('all' != $allowed_tags) {
        $output = strip_tags($output, $allowedtags);
    }

//    $output = str_replace(array("\r\n", "\r", "\n", "  "), " ", $output);

    $output = rtrim($output, "\s\n\t\r\0\x0B");
    $output = ($fix_tags) ? $output : balanceTags($output);
    $output .= ($showdots && $ellipsis) ? '...' : '';

    switch($more_tag) {
        case('div') :
            $tag = 'div';
        break;
        case('span') :
            $tag = 'span';
        break;
        case('p') :
            $tag = 'p';
        break;
        default :
            $tag = 'span';
    }

    if ($use_more_link && $more_link_text) {
        if($force_more) {
            $output .= ' <' . $tag . ' class="more-link"><a href="'. get_permalink($post->ID) . '#more-' . $post->ID .'" title="' . $more_link_title . '">' . $more_link_text . '</a></' . $tag . '>' . "\n";
        } else {
            $output .= ' <' . $tag . ' class="more-link"><a href="'. get_permalink($post->ID) . '" title="' . $more_link_title . '">' . $more_link_text . '</a></' . $tag . '>' . "\n";
        }
    }

    $output = apply_filters($filter_type, $output);

    return $output;
}


/********************************************************************/
/* SOCIALMARKER.COM BOOKMARKING SERVICE FUNCTIONS */
/********************************************************************/

function sm_utf8_to_unicode( $str ) {
 $unicode = array();
 $values = array();
 $lookingFor = 1;
  for ($i=0; $i<strlen($str);$i++) {
	$thisValue = ord( $str[ $i ] );
	if($thisValue < 128)$unicode[]=$thisValue;
    else {
	 if(count($values) == 0)$lookingFor = ($thisValue < 224)?2:3;
      $values[] = $thisValue;
     if(count($values) == $lookingFor){
      $number = ( $lookingFor == 3 ) ?
       ( ( $values[0] % 16 ) * 4096 ) + ( ( $values[1] % 64 ) * 64 ) + ( $values[2] % 64 ):
       ( ( $values[0] % 32 ) * 64 ) + ( $values[1] % 64 );
      $unicode[] = $number;
      $values = array();
      $lookingFor = 1;
     }
    }
  }
 return $unicode;
}

function sm_unicode_to_ascii($unicode){
 $entities = '';
 $unicode = sm_utf8_to_unicode($unicode);
  foreach( $unicode as $value )
    $entities .= ( $value > 127 ) ? '&#' . $value . ';' : chr( $value );
 return $entities;
}

function sm_gen_keywords($content)
{
	require_once('class.autokeyword.php');
	$params['content'] = $content; //page content
	//set the length of keywords you like
	$params['min_word_length'] = 5;  //minimum length of single words
	$params['min_word_occur'] = 5;  //minimum occur of single words
	$params['min_2words_length'] = 3;  //minimum length of words for 2 word phrases
	$params['min_2words_phrase_length'] = 10; //minimum length of 2 word phrases
	$params['min_2words_phrase_occur'] = 3; //minimum occur of 2 words phrase
	$keyword = new sm_autokeyword($params);
	return $keyword->parse_words();
}

function sm_gen_description($content, $lenght) {
	$description = substr(strip_tags(str_replace(array("\r\n", "\n", "\r", "&nbsp; &bull; &nbsp;")," ",$content)),0,$lenght);
	$poz1 = strrpos($description,".");
	if($poz1 == FALSE || substr($description, $poz1+1,1) != " ")$poz1=0;
	$poz2 = strrpos($description,"?");
	if($poz2 == FALSE || substr($description, $poz2+1,1) != " ")$poz2=0;
	$poz3 = strrpos($description,"!");
	if($poz3 == FALSE || substr($description, $poz3+1,1) != " ")$poz3=0;
	$poz = max($poz1,$poz2,$poz3);
	if($poz == 0 || $poz < $lenght-100){
		$poz = strrpos($description," ");
		$description = substr($description,0,$poz)."...";
	}else $description = substr($description,0,$poz+1);
	return $description;
}
?>